@@ -4,7 +4,7 @@
 *  Based upon CGI/Ex/Validate.pm v1.14 from Perl                     *
 *  For instructions on usage, see perldoc of CGI::Ex::Validate       *
 ***----------------------------------------------------------------**/
-// $Revision: 1.34 $
+// $Revision: 1.35 $
 
 function Validate () {
  this.error             = vob_error;
@@ -1047,7 +1047,8 @@ document.check_form = function (form, val_hash) {
  document.load_val_hash(form, val_hash);
 
  // attach handler
- form.onsubmit = function () {return document.validate(this)};
+ var orig_submit = form.onsubmit || function () { return true };
+ form.onsubmit = function (e) { return document.validate(this) && orig_submit(e, this) };
 }
 
 // the end //
