@@ -1,10 +1,10 @@
 /**----------------------------------------------------------------***
-*  Copyright 2003 - Paul Seamons                                     *
+*  Copyright 2006 - Paul Seamons                                     *
 *  Distributed under the Perl Artistic License without warranty      *
 *  Based upon YAML.pm v0.35 from Perl                                *
 ***----------------------------------------------------------------**/
 
-// $Revision: 1.15 $
+// $Revision: 1.17 $
 
 // allow for missing methods in ie 5.0
 
@@ -232,7 +232,7 @@ function yaml_parse_next_line (type) {
     type = 1;
     if (m[1].length) {
       this.offset[level + 1] = offset + m[1];
-    } else if (m = this.lines[0].match('^( *)\\S') && m[1].length > offset) {
+    } else if ((m = this.lines[0].match('^( *)\\S')) && m[1].length > offset) {
       this.offset[level + 1] = m[1].length;
     } else {
       this.offset[level + 1] = offset + 1;
